#
# spec file for package python3-Mako
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           python3-Mako
Version:        1.0.1
Release:        4.2
Url:            http://www.makotemplates.org/
Summary:        A super-fast Python templating language
License:        MIT
Group:          Development/Languages/Python
Source:         http://pypi.python.org/packages/source/M/Mako/Mako-%{version}.tar.gz
BuildRequires:  python3-MarkupSafe
BuildRequires:  python3-devel
BuildRequires:  python3-mock
BuildRequires:  python3-nose
BuildRequires:  python3-pbr
BuildRequires:  python3-setuptools
Requires:       python3-Beaker >= 1.1
Requires:       python3-MarkupSafe
BuildArch:      noarch

%description
Mako is a template library written in Python. It provides a familiar, non-XML 
syntax which compiles into Python modules for maximum performance. Mako's 
syntax and API borrows from the best ideas of many others, including Django
templates, Cheetah, Myghty, and Genshi. Conceptually, Mako is an embedded 
Python (i.e. Python Server Page) language, which refines the familiar ideas
of componentized layout and inheritance to produce one of the most 
straightforward and flexible models available, while also maintaining close 
ties to Python calling and scoping semantics.

%prep
%setup -q -n Mako-%{version}

%build
python3 setup.py build

%install
python3 setup.py install --prefix=%{_prefix} --root=%{buildroot}
mv %{buildroot}%{_bindir}/mako-render %{buildroot}%{_bindir}/mako-render-%{py3_ver}

%check
python3 setup.py test

%files
%defattr(-,root,root,-)
%doc CHANGES LICENSE README.rst examples
%{_bindir}/mako-render-%{py3_ver}
%{python3_sitelib}/mako/
%{python3_sitelib}/Mako-%{version}-py%{py3_ver}.egg-info

%changelog
* Fri Aug 21 2015 bruno@ioda-net.ch
- Add python3-pbr deps to fix build failure
* Sun Jan 25 2015 arun@gmx.de
- specfile: update copyright year
- update to version 1.0.1:
  * [feature] Added support for Lingua, a translation extraction
    system as an alternative to Babel. Pull request courtesy Wichert
    Akkerman.
  * [bug] [py3k] Modernized the examples/wsgi/run_wsgi.py file for
    Py3k. Pull requset courtesy Cody Taylor.¶
* Wed Jun 25 2014 p.drouand@gmail.com
- Update to version 1.0.0
  + Too many changes; please look at changelog in package documentation
- Replace python3-distribute with python3-setuptools in requirements
- Remove uneeded python3 and python3-2to3 BuildRequires
- Add python3-mock build require; new dependency for tests
* Fri Nov 30 2012 toddrme2178@gmail.com
- Fix building on openSUSE 12.1 and 12.2
* Thu Nov 22 2012 saschpe@suse.de
- Update to version 0.7.3:
  + [bug] legacy_html_escape function, used when
    Markupsafe isn't installed, was using an inline-compiled
    regexp which causes major slowdowns on Python 3.3;
    is now precompiled.
  + [bug] AST supporting now supports tuple-packed
    function arguments inside pure-python def
    or lambda expressions.
  + [bug] Fixed Py3K bug in the Babel extension.
  + [bug] Fixed the "filter" attribute of the
    <%%text> tag so that it pulls locally specified
    identifiers from the context the same
    way as that of <%%block> and <%%filter>.
  + [bug] Fixed bug in plugin loader to correctly
    raise exception when non-existent plugin
    is specified.
- Changes from version 0.7.2:
  + [bug] Fixed regression in 0.7.1 where AST
    parsing for Py2.4 was broken.
- Changes from version 0.7.1:
  + [feature] Control lines with no bodies will
    now succeed, as "pass" is added for these
    when no statements are otherwise present.
  + [bug] Fixed some long-broken scoping behavior
    involving variables declared in defs and such,
    which only became apparent when
    the strict_undefined flag was turned on.
  + [bug] Can now use strict_undefined at the
    same time args passed to def() are used
    by other elements of the <%%def> tag.
- The binary suffix for Python3 should be "-%%{py3_ver}"
- No need to require a specific Python ABI, RPM does that for you
* Thu Nov 22 2012 toddrme2178@gmail.com
- Remove openSUSE 11.4 spec file workarounds
* Fri May 25 2012 toddrme2178@gmail.com
- Fix building on openSUSE 11.4
- spec file cleanups
* Wed May 23 2012 highwaystar.ru@gmail.com
- python3 package added
- Update to 0.7.0
  - Added new "loop" variable to templates, is provided within a %%
    for block to provide info about the loop such as index,
    first/last, odd/even, etc.  A migration path is also provided
    for legacy templates via the "enable_loop" argument available
    on Template, TemplateLookup, and <%%page>.
  - Added a real check for "reserved" names, that is names which
    are never pulled from the context and cannot be passed to the
    template.render() method.  Current names are "context", "loop",
    "UNDEFINED".
  - The html_error_template() will now apply Pygments highlighting
    to the source code displayed in the traceback, if Pygments if
    available.
  - Added support for context managers,
    i.e. "%% with x as e:/ %% endwith" support.
  - Added class-level flag to CacheImpl "pass_context"; when True,
    the keyword argument 'context' will be passed to
    get_or_create() containing the Mako Context object.
  - Added Jinja2 to the example benchmark suite
  - Bugfixes
- Update to 0.6.2
  - Bugfixes
- Update to 0.6.1
  - Bugfixes
- Update to 0.6.0
  - Template caching has been converted into a plugin system,
    whereby the usage of Beaker is just the default plugin.
    Template and TemplateLookup now accept a string "cache_impl"
    parameter which refers to the name of a cache plugin,
    defaulting to the name 'beaker'. New plugins can be registered
    as pkg_resources entrypoints under the group "mako.cache", or
    registered directly using mako.cache.register_plugin().  The
    core plugin is the mako.cache.CacheImpl class.
  - Added support for Beaker cache regions in templates. Usage of
    regions should be considered as superseding the very obsolete
    idea of passing in backend options, timeouts, etc. within
    templates.
  - The 'put' method on Cache is now 'set'. 'put' is there for
    backwards compatibility.
  - The <%%def>, <%%block> and <%%page> tags now accept any argument
    named "cache_*", and the key minus the "cache_" prefix will be
    passed as keyword arguments to the CacheImpl methods.
  - Template and TemplateLookup now accept an argument cache_args,
    which refers to a dictionary containing cache parameters. The
    cache_dir, cache_url, cache_type, cache_timeout arguments are
    deprecated (will probably never be removed, however) and can be
    passed now as cache_args={'url':<some url>, 'type':'memcached',
    'timeout':50, 'dir':'/path/to/some/directory'}
  - Can now refer to context variables within extra arguments to
    <%%block>, <%%def>,
    i.e. <%%block name="foo" cache_key="${somekey}">. Filters can
    also be used in this way,
    i.e. <%%def name="foo()" filter="myfilter"> then
    template.render(myfilter=some_callable)
  - Added "--var name=value" option to the mako-render script,
    allows passing of kw to the template from the command line.
  - Added module_writer argument to Template, TemplateLookup,
    allows a callable to be passed which takes over the writing of
    the template's module source file, so that special
    environment-specific steps can be taken.
  - Bugfixes
